Example Photometric Pipeline Parameters
=======================================

The spectroscopic pipeline creates a :code:`phot` object from a parameter file.
The example below shows some example parameters.
A library of parameter files is available at https://github.com/eas342/tshirt/tree/master/tshirt/parameters/spec_params

.. literalinclude:: ../../tshirt/parameters/phot_params/example_phot_parameters.yaml

..   :language: yaml

